package cz.cvut.fel.cs.ass.singleton.impl;
import java.io.WriteAbortedException;
import java.util.HashMap;
import java.util.Map;

import cz.cvut.fel.cs.ass.singleton.FileSystem;

public class SafeFileSystem implements FileSystem {

	private static int counter = 1;
	private int id;
	private Map<String, String> files = new HashMap<String, String>();

	public SafeFileSystem() {
		id = counter++;
		new LoggerImpl().log(this.getClass(), id, "Init");
	}

	/* (non-Javadoc)
	 * @see FileSystem#contains(java.lang.String)
	 */
	@Override
	public boolean contains(String name) {
		return files.containsKey(name);
	}

	/* (non-Javadoc)
	 * @see FileSystem#write(java.lang.String, java.lang.String)
	 */
	@Override
	public synchronized void write(String name, String content) throws Exception {
		if (files.containsKey(name)) {
			throw new WriteAbortedException("File " + name + " already exists, content '" +content + "' not written",
					null);
		}
		files.put(name, content);
		new LoggerImpl().log(this.getClass(), id, "Writing file: " + name);
	}

	/* (non-Javadoc)
	 * @see FileSystem#read(java.lang.String)
	 */
	@Override
	public synchronized String read(String name) throws Exception {
		if (!files.containsKey(name)) {
			throw new Exception("File " + name
					+ " does not exist in FileSystem - cannot read" );
		}
		String out = files.remove(name);
		new LoggerImpl().log(this.getClass(), id, "Reading/removing file: " + name);
		return out;
	}

}
